"""add TorrentLink.cached

Revision ID: 4af79c08de
Revises: None
Create Date: 2014-08-06 17:19:04.568826

"""

# revision identifiers, used by Alembic.
revision = '4af79c08de'
down_revision = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('torrent_link', sa.Column('cached', sa.Boolean(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('torrent_link', 'cached')
    ### end Alembic commands ###
